/* This file was generated by syncqt. */
#ifndef QT_QTPROTOBUF_VERSION_H
#define QT_QTPROTOBUF_VERSION_H

#define QTPROTOBUF_VERSION_STR "6.12.0"

#define QTPROTOBUF_VERSION 0x0601200

#endif // QT_QTPROTOBUF_VERSION_H
